---
permalink: /manual/
---

# Benutzerhandbuch

Willkommen beim KMUHelper!

Diese Bedienungsanleitung sollte Ihnen dazu helfen, den KMUHelper zu verstehen und ihn zu benutzen.

Diese Anleitung setzt die [Installation](../installation.md) des KMUHelper voraus.

## Inhalt

-   [Einrichtung](setup.md)
-   [App](app.md)
-   [Lagermanagement](storage.md)

Hinweis: Zu Demonstrationszwecken werden in dieser Bedienungsanleitung relative Urls oder die Domain `example.com` verwendet. In beiden Fällen sollten Sie diese mit Ihrer Domain ergänzen bzw. ersetzen.
